# MLExtreme

## Main references 
The package mainly implements methods developed and analysed in the following papers: 

- Supervised learning on heavy-tailed, extreme covariates
	
	- Jalalzai, H., Clémençon, S., & Sabourin, A. (2018). On binary classification in extreme regions. Advances in Neural Information Processing Systems, 31.
	
	- Clémençon, S., Jalalzai, H., Lhaut, S., Sabourin, A., & Segers, J. (2023). Concentration bounds for the empirical angular measure with statistical learning applications. Bernoulli, 29(4), 2797-2827.
	
	- Huet, N., Clémençon, S., & Sabourin, A. (2023). On regression in extreme regions. arXiv preprint arXiv:2303.03084.
	
	- Aghbalou, A., Bertail, P., Portier, F., & Sabourin, A. (2024). Cross-validation on extreme regions. Extremes, 27(4), 505-555.
	
   
- Principal Component Analysis for multivariate extremes 
	
	- Drees, H., & Sabourin, A. (2021). Principal component analysis for multivariate extremes.
	
	
- Mass-Volume set estimation for multivariate extremes, and anomaly detection 
	
	- Thomas, A., Clémençon, S., Gramfort, A., & Sabourin, A. (2017, April). Anomaly Detection in Extreme Regions via Empirical MV-sets on the Sphere. In AISTATS (Vol. 54).

- Support identification and feature clustering for multivariate extremes 
	
	- Goix, N., Sabourin, A., & Clémençon, S. (2017). Sparse representation of multivariate extremes with applications to anomaly detection. Journal of Multivariate Analysis, 161, 12-31.
	
	- Goix, N., Sabourin, A., & Clémençon, S. (2016, May). Sparse representation of multivariate extremes with applications to anomaly ranking. In Artificial intelligence and statistics (pp. 75-83). PMLR.
	
	- Chiapino, M., & Sabourin, A. (2016, September). Feature clustering for extreme events analysis, with application to extreme stream-flow data. In International workshop on new frontiers in mining complex patterns (pp. 132-147). Cham: Springer International Publishing.
	
	- Chiapino, M., Sabourin, A., & Segers, J. (2019). Identifying groups of variables with the potential of being large simultaneously. Extremes, 22, 193-222.
	
## Aditional references 

- Multivariate Threshold choice 

	- Wan, P., & Davis, R. A. (2019). Threshold selection for multivariate heavy-tailed data. Extremes, 22(1), 131-166.
   
- Functional version of PCA for extremes, variants avoiding negative components
  
    - Cooley, D., & Thibaud, E. (2019). Decompositions of dependence for high-dimensional extremes. Biometrika, 106(3), 587-604.
	
	- Clémençon, S., Huet, N., & Sabourin, A. (2024). Regular variation in Hilbert spaces and principal component analysis for functional extremes. Stochastic Processes and their Applications, 174, 104375.
  
- Tolerance parameter selection for feature clustering, dispersion models: 
	
	-  Cordeiro, G. M., Labouriau, R., & Botter, D. A. (2021). \
An introduction to Bent Jørgensen’s ideas. Brazilian Journal of Probability and Statistics, 35(1), 2-20.

	- Jorgensen, B. (1987). Exponential dispersion models. \
Journal of the Royal Statistical Society Series B: Statistical Methodology, \
49(2), 127-145.

	- Jorgensen, B. (1997). The theory of dispersion models. CRC Press.



## Author
- Anne Sabourin ([anne.sabourin@math.cnrs.fr](mailto:anne.sabourin@math.cnrs.fr))

## Packaging
- Pierre-Antoine Amiand-Leroy ([Pierre-Antoine.AMIAND-LEROY@ip-paris.fr](mailto:Pierre-Antoine.AMIAND-LEROY@ip-paris.fr))
- Stephan Clémençon ([stephan.clemencon@telecom-paris.fr](mailto:stephan.clemencon@telecom-paris.fr))

## Code Contributors
- Maël Chiapino
- Nicolas Goix
- Nathan Huet
- Albert Thomas

## Acknowledgments

We would like to acknowledge the French CNRS research agency for their support, which was essential in providing the necessary resources for the development of this package.

Our thanks also go to Hi! Paris for their assistance in the packaging process, with special mention to Research Engineer Pierre-Antoine Amiand-Leroy.

We are grateful to Stephan Clémençon for his initial guidance and continued support throughout the project.

Finally, this package reflects the collective efforts of several past PhD students, whose contributions have been vital to its development.

## License
This project is licensed under the [MIT License](LICENSE).

